import axios from "axios";
import express from "express";
import _ from "lodash";
import { apiSelector } from "../../../utils/apiSelector";
import { generateMergedWav } from "../../../utils/generateMergedWav";

type Payload = {
  text_cn?: string;
  text_pt?: string;
  text_en?: string;
  centerCode: "CIMM" | "CIVA";
  times: number;
  isInsert: "Y" | "N";
  order: string;
}

type Response = {
  isSuccess: boolean;
  mergedText?: string;
}

export default async function (req:express.Request<any, any, Payload>, res:express.Response<Response>) {
  try {
    const {text_cn, text_pt, text_en, times, order, centerCode} = req.body;

    if (
      !times ||
      times < 1 ||
      times > 9 ||
      !order?.split(",").every(x => ["cn", "pt", "en"].includes(x.trim())) ||
      !["CIVA", "CIMM"].includes(centerCode)
    ) {
      console.log("Payload", JSON.stringify(req.body));
      throw new Error("Invalid Payload");
    }
    const timestamp = Date.now();

    const data = await generateMergedWav(req.body);

    const { data: responseData } = await axios.post(`${apiSelector(centerCode)}/queue`, {
      id: timestamp,
      text_cn,
      text_pt,
      text_en,
      centerCode,
      times,
      order,
      filename: `${timestamp}.wav`,
      data: data.toString("base64")
    });
    
    return res.json(responseData);
  } catch (err) {
    console.error(err);
    return res.json({isSuccess: false})
  }
};