import express from "express";
import _ from "lodash";
import { generateMergedWav } from "../../../utils/generateMergedWav";

type Payload = {
  text_cn?: string;
  text_pt?: string;
  text_en?: string;
  centerCode: "CIMM" | "CIVA";
  times: number;
  isInsert: "Y" | "N";
  order: string;
}

export default async function (req:express.Request<any, any, Payload>, res:express.Response) {
  try {
    const {text_cn, text_pt, text_en, order} = req.body;

    if (!order?.split(",").every(x => ["cn", "pt", "en"].includes(x))) {
      console.log("Payload", JSON.stringify(req.body));
      throw new Error("Invalid Payload");
    }

    const data = await generateMergedWav({
      text_cn,
      text_pt,
      text_en,
      order,
      times: 1
    });

    return res.type(".wav").send(data);
  } catch (err) {
    console.error(err);
    return res.json({isSuccess: false})
  }
};