import _ from "lodash";
import { exportWav } from "./speak";
import fs from "fs";
import os from "os";
import path from "path";
const audioconcat = require("wav-concat");

type Payload = {
  text_cn?: string;
  text_pt?: string;
  text_en?: string;
  times: number;
  order: string;
}

export async function generateMergedWav(body:Payload) {
  const {text_cn, text_pt, text_en, times, order} = body;

  const orderArray = order.split(',');

  const tempFolder = fs.mkdtempSync(path.join(os.tmpdir(), 'tts-'));

  await Promise.all([
    exportWav("cn", path.join(tempFolder, "cn.wav"), text_cn),
    exportWav("pt", path.join(tempFolder, "pt.wav"), text_pt),
    exportWav("en", path.join(tempFolder, "en.wav"), text_en),
  ]);

  const wavList = _.chain(Array(times))
  .map(() => orderArray.map(lang => {
    switch (lang) {
      case "cn": return text_cn && path.join(tempFolder, "cn.wav");
      case "pt": return text_pt && path.join(tempFolder, "pt.wav");
      case "en": return text_en && path.join(tempFolder, "en.wav");
      default: return undefined;
    }
  }))
  .flatten()
  .compact()
  .value();

  const mergedWavPath = path.join(tempFolder, "merged.wav");
  const concatAudio = () => new Promise((resolve, reject) => audioconcat(wavList).concat(mergedWavPath).on("error", (err:any, stderr:any) => reject(`${err}, ${stderr}`)).on("end", (output:string) => resolve(output)));

  await concatAudio();

  const data = fs.readFileSync(mergedWavPath);
  fs.rmSync(tempFolder, { recursive: true });

  return data;
}